# 
# Generated by the nebius.base.protos.compiler.  DO NOT EDIT!
# 

"""Auto-generated Nebius SDK package for ``nebius.billing.v1alpha1``"""

import builtins as builtins
import collections.abc as abc
import datetime as datetime
import google.protobuf.descriptor as descriptor_1
import google.protobuf.message as message_1
import google.protobuf.timestamp_pb2 as timestamp_pb2
import nebius.aio.client as client
import nebius.aio.operation as operation
import nebius.aio.request as request_1
import nebius.aio.request_kwargs as request_kwargs
import nebius.api.nebius.billing.v1alpha1.billing_report_exporter_pb2 as billing_report_exporter_pb2
import nebius.api.nebius.billing.v1alpha1.calculator_pb2 as calculator_pb2
import nebius.api.nebius.billing.v1alpha1.calculator_service_pb2 as calculator_service_pb2
import nebius.api.nebius.billing.v1alpha1.offer_type_pb2 as offer_type_pb2
import nebius.api.nebius.billing.v1alpha1.one_time_export_pb2 as one_time_export_pb2
import nebius.api.nebius.billing.v1alpha1.one_time_export_service_pb2 as one_time_export_service_pb2
import nebius.api.nebius.common.v1 as v1_2
import nebius.api.nebius.common.v1.error_pb2 as error_pb2
import nebius.api.nebius.common.v1.metadata_pb2 as metadata_pb2
import nebius.api.nebius.common.v1.operation_pb2 as operation_pb2
import nebius.api.nebius.compute.v1 as v1_1
import nebius.api.nebius.compute.v1.disk_service_pb2 as disk_service_pb2
import nebius.api.nebius.compute.v1.filesystem_service_pb2 as filesystem_service_pb2
import nebius.api.nebius.compute.v1.instance_service_pb2 as instance_service_pb2
import nebius.base.protos.descriptor as descriptor
import nebius.base.protos.pb_classes as pb_classes
import nebius.base.protos.pb_enum as pb_enum
import nebius.base.protos.unset as unset
import nebius.base.protos.well_known as well_known_1
import typing as typing
import typing_extensions as typing_extensions
#@ local imports here @#

# file: nebius/billing/v1alpha1/billing_report_exporter.proto
class ExportFormat(pb_enum.Enum):
    """
    Supported export formats for billing reports.
    """
    
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.EnumDescriptor](".nebius.billing.v1alpha1.ExportFormat",billing_report_exporter_pb2.DESCRIPTOR,descriptor_1.EnumDescriptor)
    EXPORT_FORMAT_UNSPECIFIED = 0
    EXPORT_FORMAT_FOCUS_1_2_CSV = 1
    """
    FOCUS (FinOps Open Cost and Usage Specification) v1.2 CSV format.
    See: https://focus.finops.org/focus-specification/v1-2/
    """
    

# file: nebius/billing/v1alpha1/calculator.proto
class ResourceSpec(pb_classes.Message):
    """
    Resource specification for cost estimation.
    Contains the specifications for creating and updating different types of resources.
    """
    
    __PB2_CLASS__ = calculator_pb2.ResourceSpec
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.billing.v1alpha1.ResourceSpec",calculator_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    class __OneOfClass_resource_spec__(pb_classes.OneOf):
        name: builtins.str= "resource_spec"
        
        def __init__(self, msg: "ResourceSpec") -> None:
            super().__init__()
            self._message: "ResourceSpec" = msg
    
    class __OneOfClass_resource_spec_compute_instance_spec__(__OneOfClass_resource_spec__):
        field: typing.Literal["compute_instance_spec"] = "compute_instance_spec"
        
        def __init__(self, msg: "ResourceSpec") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "v1_1.CreateInstanceRequest":
            return self._message.compute_instance_spec
    
    class __OneOfClass_resource_spec_compute_instance_update_spec__(__OneOfClass_resource_spec__):
        field: typing.Literal["compute_instance_update_spec"] = "compute_instance_update_spec"
        
        def __init__(self, msg: "ResourceSpec") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "v1_1.UpdateInstanceRequest":
            return self._message.compute_instance_update_spec
    
    class __OneOfClass_resource_spec_compute_disk_spec__(__OneOfClass_resource_spec__):
        field: typing.Literal["compute_disk_spec"] = "compute_disk_spec"
        
        def __init__(self, msg: "ResourceSpec") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "v1_1.CreateDiskRequest":
            return self._message.compute_disk_spec
    
    class __OneOfClass_resource_spec_compute_disk_update_spec__(__OneOfClass_resource_spec__):
        field: typing.Literal["compute_disk_update_spec"] = "compute_disk_update_spec"
        
        def __init__(self, msg: "ResourceSpec") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "v1_1.UpdateDiskRequest":
            return self._message.compute_disk_update_spec
    
    class __OneOfClass_resource_spec_compute_filesystem_spec__(__OneOfClass_resource_spec__):
        field: typing.Literal["compute_filesystem_spec"] = "compute_filesystem_spec"
        
        def __init__(self, msg: "ResourceSpec") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "v1_1.CreateFilesystemRequest":
            return self._message.compute_filesystem_spec
    
    class __OneOfClass_resource_spec_compute_filesystem_update_spec__(__OneOfClass_resource_spec__):
        field: typing.Literal["compute_filesystem_update_spec"] = "compute_filesystem_update_spec"
        
        def __init__(self, msg: "ResourceSpec") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "v1_1.UpdateFilesystemRequest":
            return self._message.compute_filesystem_update_spec
    
    @builtins.property
    def resource_spec(self) -> __OneOfClass_resource_spec_compute_instance_spec__|__OneOfClass_resource_spec_compute_instance_update_spec__|__OneOfClass_resource_spec_compute_disk_spec__|__OneOfClass_resource_spec_compute_disk_update_spec__|__OneOfClass_resource_spec_compute_filesystem_spec__|__OneOfClass_resource_spec_compute_filesystem_update_spec__|None:
        field_name_1: str|None = super().which_field_in_oneof("resource_spec")
        match field_name_1:
            case "compute_instance_spec":
                return self.__OneOfClass_resource_spec_compute_instance_spec__(self)
            case "compute_instance_update_spec":
                return self.__OneOfClass_resource_spec_compute_instance_update_spec__(self)
            case "compute_disk_spec":
                return self.__OneOfClass_resource_spec_compute_disk_spec__(self)
            case "compute_disk_update_spec":
                return self.__OneOfClass_resource_spec_compute_disk_update_spec__(self)
            case "compute_filesystem_spec":
                return self.__OneOfClass_resource_spec_compute_filesystem_spec__(self)
            case "compute_filesystem_update_spec":
                return self.__OneOfClass_resource_spec_compute_filesystem_update_spec__(self)
            case None:
                return None
            case _:
                raise pb_classes.OneOfMatchError(field_name_1)
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        compute_instance_spec: "v1_1.CreateInstanceRequest|instance_service_pb2.CreateInstanceRequest|None|unset.UnsetType" = unset.Unset,
        compute_instance_update_spec: "v1_1.UpdateInstanceRequest|instance_service_pb2.UpdateInstanceRequest|None|unset.UnsetType" = unset.Unset,
        compute_disk_spec: "v1_1.CreateDiskRequest|disk_service_pb2.CreateDiskRequest|None|unset.UnsetType" = unset.Unset,
        compute_disk_update_spec: "v1_1.UpdateDiskRequest|disk_service_pb2.UpdateDiskRequest|None|unset.UnsetType" = unset.Unset,
        compute_filesystem_spec: "v1_1.CreateFilesystemRequest|filesystem_service_pb2.CreateFilesystemRequest|None|unset.UnsetType" = unset.Unset,
        compute_filesystem_update_spec: "v1_1.UpdateFilesystemRequest|filesystem_service_pb2.UpdateFilesystemRequest|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(compute_instance_spec, unset.UnsetType):
            self.compute_instance_spec = compute_instance_spec
        if not isinstance(compute_instance_update_spec, unset.UnsetType):
            self.compute_instance_update_spec = compute_instance_update_spec
        if not isinstance(compute_disk_spec, unset.UnsetType):
            self.compute_disk_spec = compute_disk_spec
        if not isinstance(compute_disk_update_spec, unset.UnsetType):
            self.compute_disk_update_spec = compute_disk_update_spec
        if not isinstance(compute_filesystem_spec, unset.UnsetType):
            self.compute_filesystem_spec = compute_filesystem_spec
        if not isinstance(compute_filesystem_update_spec, unset.UnsetType):
            self.compute_filesystem_update_spec = compute_filesystem_update_spec
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "compute_instance_spec",
            "compute_instance_update_spec",
            "compute_disk_spec",
            "compute_disk_update_spec",
            "compute_filesystem_spec",
            "compute_filesystem_update_spec",
            "resource_spec",
        ]
    
    @builtins.property
    def compute_instance_spec(self) -> "v1_1.CreateInstanceRequest|None":
        return super()._get_field("compute_instance_spec", explicit_presence=True,
        wrap=v1_1.CreateInstanceRequest,
        )
    @compute_instance_spec.setter
    def compute_instance_spec(self, value: "v1_1.CreateInstanceRequest|instance_service_pb2.CreateInstanceRequest|None") -> None:
        return super()._set_field("compute_instance_spec",value,explicit_presence=True,
        )
    
    @builtins.property
    def compute_instance_update_spec(self) -> "v1_1.UpdateInstanceRequest|None":
        return super()._get_field("compute_instance_update_spec", explicit_presence=True,
        wrap=v1_1.UpdateInstanceRequest,
        )
    @compute_instance_update_spec.setter
    def compute_instance_update_spec(self, value: "v1_1.UpdateInstanceRequest|instance_service_pb2.UpdateInstanceRequest|None") -> None:
        return super()._set_field("compute_instance_update_spec",value,explicit_presence=True,
        )
    
    @builtins.property
    def compute_disk_spec(self) -> "v1_1.CreateDiskRequest|None":
        return super()._get_field("compute_disk_spec", explicit_presence=True,
        wrap=v1_1.CreateDiskRequest,
        )
    @compute_disk_spec.setter
    def compute_disk_spec(self, value: "v1_1.CreateDiskRequest|disk_service_pb2.CreateDiskRequest|None") -> None:
        return super()._set_field("compute_disk_spec",value,explicit_presence=True,
        )
    
    @builtins.property
    def compute_disk_update_spec(self) -> "v1_1.UpdateDiskRequest|None":
        return super()._get_field("compute_disk_update_spec", explicit_presence=True,
        wrap=v1_1.UpdateDiskRequest,
        )
    @compute_disk_update_spec.setter
    def compute_disk_update_spec(self, value: "v1_1.UpdateDiskRequest|disk_service_pb2.UpdateDiskRequest|None") -> None:
        return super()._set_field("compute_disk_update_spec",value,explicit_presence=True,
        )
    
    @builtins.property
    def compute_filesystem_spec(self) -> "v1_1.CreateFilesystemRequest|None":
        return super()._get_field("compute_filesystem_spec", explicit_presence=True,
        wrap=v1_1.CreateFilesystemRequest,
        )
    @compute_filesystem_spec.setter
    def compute_filesystem_spec(self, value: "v1_1.CreateFilesystemRequest|filesystem_service_pb2.CreateFilesystemRequest|None") -> None:
        return super()._set_field("compute_filesystem_spec",value,explicit_presence=True,
        )
    
    @builtins.property
    def compute_filesystem_update_spec(self) -> "v1_1.UpdateFilesystemRequest|None":
        return super()._get_field("compute_filesystem_update_spec", explicit_presence=True,
        wrap=v1_1.UpdateFilesystemRequest,
        )
    @compute_filesystem_update_spec.setter
    def compute_filesystem_update_spec(self, value: "v1_1.UpdateFilesystemRequest|filesystem_service_pb2.UpdateFilesystemRequest|None") -> None:
        return super()._set_field("compute_filesystem_update_spec",value,explicit_presence=True,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "compute_instance_spec":"compute_instance_spec",
        "compute_instance_update_spec":"compute_instance_update_spec",
        "compute_disk_spec":"compute_disk_spec",
        "compute_disk_update_spec":"compute_disk_update_spec",
        "compute_filesystem_spec":"compute_filesystem_spec",
        "compute_filesystem_update_spec":"compute_filesystem_update_spec",
        "resource_spec":"resource_spec",
    }
    
class ResourceGroupCost(pb_classes.Message):
    """
    Cost information for a group of resources.
    """
    
    __PB2_CLASS__ = calculator_pb2.ResourceGroupCost
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.billing.v1alpha1.ResourceGroupCost",calculator_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    class __OneOfClass_cost_type__(pb_classes.OneOf):
        name: builtins.str= "cost_type"
        
        def __init__(self, msg: "ResourceGroupCost") -> None:
            super().__init__()
            self._message: "ResourceGroupCost" = msg
    
    class __OneOfClass_cost_type_general__(__OneOfClass_cost_type__):
        field: typing.Literal["general"] = "general"
        
        def __init__(self, msg: "ResourceGroupCost") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "GeneralTotalCost":
            return self._message.general
    
    @builtins.property
    def cost_type(self) -> __OneOfClass_cost_type_general__|None:
        field_name_1: str|None = super().which_field_in_oneof("cost_type")
        match field_name_1:
            case "general":
                return self.__OneOfClass_cost_type_general__(self)
            case None:
                return None
            case _:
                raise pb_classes.OneOfMatchError(field_name_1)
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        general: "GeneralTotalCost|calculator_pb2.GeneralTotalCost|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(general, unset.UnsetType):
            self.general = general
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "general",
            "cost_type",
        ]
    
    @builtins.property
    def general(self) -> "GeneralTotalCost|None":
        """
        Fixed total cost calculation.
        Used when the total cost is deterministic and doesn't vary.
        """
        
        return super()._get_field("general", explicit_presence=True,
        wrap=GeneralTotalCost,
        )
    @general.setter
    def general(self, value: "GeneralTotalCost|calculator_pb2.GeneralTotalCost|None") -> None:
        return super()._set_field("general",value,explicit_presence=True,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "general":"general",
        "cost_type":"cost_type",
    }
    
class GeneralTotalCost(pb_classes.Message):
    """
    General total cost with a single fixed amount.
    Used for resources with predictable, non-variable pricing.
    """
    
    __PB2_CLASS__ = calculator_pb2.GeneralTotalCost
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.billing.v1alpha1.GeneralTotalCost",calculator_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        total: "CostBreakdown|calculator_pb2.CostBreakdown|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(total, unset.UnsetType):
            self.total = total
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "total",
        ]
    
    @builtins.property
    def total(self) -> "CostBreakdown":
        """
        Cost breakdown including all SKUs and their individual costs.
        """
        
        return super()._get_field("total", explicit_presence=False,
        wrap=CostBreakdown,
        )
    @total.setter
    def total(self, value: "CostBreakdown|calculator_pb2.CostBreakdown|None") -> None:
        return super()._set_field("total",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "total":"total",
    }
    
class GeneralResourceCost(pb_classes.Message):
    """
    General resource cost for single-unit resources.
    Used for resources like compute instances or disks where the unit count is not variable.
    """
    
    __PB2_CLASS__ = calculator_pb2.GeneralResourceCost
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.billing.v1alpha1.GeneralResourceCost",calculator_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        total: "CostBreakdown|calculator_pb2.CostBreakdown|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(total, unset.UnsetType):
            self.total = total
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "total",
        ]
    
    @builtins.property
    def total(self) -> "CostBreakdown":
        """
        Cost breakdown for the resource including all SKU costs and total cost.
        """
        
        return super()._get_field("total", explicit_presence=False,
        wrap=CostBreakdown,
        )
    @total.setter
    def total(self, value: "CostBreakdown|calculator_pb2.CostBreakdown|None") -> None:
        return super()._set_field("total",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "total":"total",
    }
    
class CostBreakdown(pb_classes.Message):
    """
    Detailed cost breakdown showing individual SKU costs and totals.
    """
    
    __PB2_CLASS__ = calculator_pb2.CostBreakdown
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.billing.v1alpha1.CostBreakdown",calculator_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        cost: "builtins.str|None|unset.UnsetType" = unset.Unset,
        cost_rounded: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(cost, unset.UnsetType):
            self.cost = cost
        if not isinstance(cost_rounded, unset.UnsetType):
            self.cost_rounded = cost_rounded
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "cost",
            "cost_rounded",
        ]
    
    @builtins.property
    def cost(self) -> "builtins.str":
        """
        Total cost as a decimal string.
        Represents the sum of all SKU costs with full precision.
        Example: "42.123456789" for precise billing calculations.
        """
        
        return super()._get_field("cost", explicit_presence=False,
        )
    @cost.setter
    def cost(self, value: "builtins.str|None") -> None:
        return super()._set_field("cost",value,explicit_presence=False,
        )
    
    @builtins.property
    def cost_rounded(self) -> "builtins.str":
        """
        Total cost rounded up to 2 decimal places.
        Example: "42.13"
        """
        
        return super()._get_field("cost_rounded", explicit_presence=False,
        )
    @cost_rounded.setter
    def cost_rounded(self, value: "builtins.str|None") -> None:
        return super()._set_field("cost_rounded",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "cost":"cost",
        "cost_rounded":"cost_rounded",
    }
    
# file: nebius/billing/v1alpha1/offer_type.proto
class OfferType(pb_enum.Enum):
    """
    OfferType is a enum that specifies the type of offer.
    """
    
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.EnumDescriptor](".nebius.billing.v1alpha1.OfferType",offer_type_pb2.DESCRIPTOR,descriptor_1.EnumDescriptor)
    OFFER_TYPE_UNSPECIFIED = 0
    OFFER_TYPE_CONTRACT_PRICE = 1
    """
    Contract price is a special price for SKU.
    """
    

# file: nebius/billing/v1alpha1/calculator_service.proto
class EstimateRequest(pb_classes.Message):
    __PB2_CLASS__ = calculator_service_pb2.EstimateRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.billing.v1alpha1.EstimateRequest",calculator_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        resource_spec: "ResourceSpec|calculator_pb2.ResourceSpec|None|unset.UnsetType" = unset.Unset,
        offer_types: "abc.Iterable[OfferType]|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(resource_spec, unset.UnsetType):
            self.resource_spec = resource_spec
        if not isinstance(offer_types, unset.UnsetType):
            self.offer_types = offer_types
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "resource_spec",
            "offer_types",
        ]
    
    @builtins.property
    def resource_spec(self) -> "ResourceSpec":
        """
        Resource specification for cost estimation.
        Must contain exactly one resource type.
        """
        
        return super()._get_field("resource_spec", explicit_presence=False,
        wrap=ResourceSpec,
        )
    @resource_spec.setter
    def resource_spec(self, value: "ResourceSpec|calculator_pb2.ResourceSpec|None") -> None:
        return super()._set_field("resource_spec",value,explicit_presence=False,
        )
    
    @builtins.property
    def offer_types(self) -> "abc.MutableSequence[OfferType]":
        """
        Type of offers to be applied to the cost estimate.
        """
        
        return super()._get_field("offer_types", explicit_presence=False,
        wrap=pb_classes.Repeated,
        )
    @offer_types.setter
    def offer_types(self, value: "abc.Iterable[OfferType]|None") -> None:
        return super()._set_field("offer_types",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "resource_spec":"resource_spec",
        "offer_types":"offer_types",
    }
    
class EstimateResponse(pb_classes.Message):
    __PB2_CLASS__ = calculator_service_pb2.EstimateResponse
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.billing.v1alpha1.EstimateResponse",calculator_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        hourly_cost: "ResourceGroupCost|calculator_pb2.ResourceGroupCost|None|unset.UnsetType" = unset.Unset,
        monthly_cost: "ResourceGroupCost|calculator_pb2.ResourceGroupCost|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(hourly_cost, unset.UnsetType):
            self.hourly_cost = hourly_cost
        if not isinstance(monthly_cost, unset.UnsetType):
            self.monthly_cost = monthly_cost
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "hourly_cost",
            "monthly_cost",
        ]
    
    @builtins.property
    def hourly_cost(self) -> "ResourceGroupCost":
        """
        Estimated hourly cost for the resource.
        """
        
        return super()._get_field("hourly_cost", explicit_presence=False,
        wrap=ResourceGroupCost,
        )
    @hourly_cost.setter
    def hourly_cost(self, value: "ResourceGroupCost|calculator_pb2.ResourceGroupCost|None") -> None:
        return super()._set_field("hourly_cost",value,explicit_presence=False,
        )
    
    @builtins.property
    def monthly_cost(self) -> "ResourceGroupCost":
        """
        Estimated monthly cost for the resource.
        Calculated as hourly_cost * 24 * 30 (720 hours) for resources running continuously.
        """
        
        return super()._get_field("monthly_cost", explicit_presence=False,
        wrap=ResourceGroupCost,
        )
    @monthly_cost.setter
    def monthly_cost(self, value: "ResourceGroupCost|calculator_pb2.ResourceGroupCost|None") -> None:
        return super()._set_field("monthly_cost",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "hourly_cost":"hourly_cost",
        "monthly_cost":"monthly_cost",
    }
    
class EstimateBatchRequest(pb_classes.Message):
    __PB2_CLASS__ = calculator_service_pb2.EstimateBatchRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.billing.v1alpha1.EstimateBatchRequest",calculator_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        resource_specs: "abc.Iterable[ResourceSpec]|None|unset.UnsetType" = unset.Unset,
        offer_types: "abc.Iterable[OfferType]|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(resource_specs, unset.UnsetType):
            self.resource_specs = resource_specs
        if not isinstance(offer_types, unset.UnsetType):
            self.offer_types = offer_types
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "resource_specs",
            "offer_types",
        ]
    
    @builtins.property
    def resource_specs(self) -> "abc.MutableSequence[ResourceSpec]":
        """
        List of resource specifications for cost estimation.
        Each resource will be priced individually and then aggregated into total costs.
        """
        
        return super()._get_field("resource_specs", explicit_presence=False,
        wrap=pb_classes.Repeated.with_wrap(ResourceSpec,None,None),
        )
    @resource_specs.setter
    def resource_specs(self, value: "abc.Iterable[ResourceSpec]|None") -> None:
        return super()._set_field("resource_specs",value,explicit_presence=False,
        )
    
    @builtins.property
    def offer_types(self) -> "abc.MutableSequence[OfferType]":
        """
        Type of offers to be applied to the cost estimate.
        """
        
        return super()._get_field("offer_types", explicit_presence=False,
        wrap=pb_classes.Repeated,
        )
    @offer_types.setter
    def offer_types(self, value: "abc.Iterable[OfferType]|None") -> None:
        return super()._set_field("offer_types",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "resource_specs":"resource_specs",
        "offer_types":"offer_types",
    }
    
class EstimateBatchResponse(pb_classes.Message):
    __PB2_CLASS__ = calculator_service_pb2.EstimateBatchResponse
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.billing.v1alpha1.EstimateBatchResponse",calculator_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        hourly_cost: "ResourceGroupCost|calculator_pb2.ResourceGroupCost|None|unset.UnsetType" = unset.Unset,
        monthly_cost: "ResourceGroupCost|calculator_pb2.ResourceGroupCost|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(hourly_cost, unset.UnsetType):
            self.hourly_cost = hourly_cost
        if not isinstance(monthly_cost, unset.UnsetType):
            self.monthly_cost = monthly_cost
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "hourly_cost",
            "monthly_cost",
        ]
    
    @builtins.property
    def hourly_cost(self) -> "ResourceGroupCost":
        """
        Estimated hourly cost for all resources in the batch.
        """
        
        return super()._get_field("hourly_cost", explicit_presence=False,
        wrap=ResourceGroupCost,
        )
    @hourly_cost.setter
    def hourly_cost(self, value: "ResourceGroupCost|calculator_pb2.ResourceGroupCost|None") -> None:
        return super()._set_field("hourly_cost",value,explicit_presence=False,
        )
    
    @builtins.property
    def monthly_cost(self) -> "ResourceGroupCost":
        """
        Estimated monthly cost for all resources in the batch.
        Calculated as hourly_cost * 24 * 30 (720 hours) for resources running continuously.
        """
        
        return super()._get_field("monthly_cost", explicit_presence=False,
        wrap=ResourceGroupCost,
        )
    @monthly_cost.setter
    def monthly_cost(self, value: "ResourceGroupCost|calculator_pb2.ResourceGroupCost|None") -> None:
        return super()._set_field("monthly_cost",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "hourly_cost":"hourly_cost",
        "monthly_cost":"monthly_cost",
    }
    

class CalculatorServiceClient(client.Client):
    """
    Calculator service for estimating resource costs.
    
    This class provides the client methods for the ``.nebius.billing.v1alpha1.CalculatorService`` service.
    
    Each method constructs a :class:`nebius.aio.request.Request` object
    that represents the in-flight RPC. The request can be awaited (async)
    or waited synchronously using its ``.wait()`` helpers.
    
    The request methods accept various parameters to configure metadata,
    timeouts, authorization, and retries. See individual method docstrings
    for details.
    
    :cvar __service_name__: The full protobuf service name.
    """
    
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.ServiceDescriptor](".nebius.billing.v1alpha1.CalculatorService",calculator_service_pb2.DESCRIPTOR,descriptor_1.ServiceDescriptor)
    """The protobuf service descriptor extraction function."""
    __service_name__ = ".nebius.billing.v1alpha1.CalculatorService"
    
    def estimate(self,
        request: "EstimateRequest",
        **kwargs: typing_extensions.Unpack[request_kwargs.RequestKwargs]
    ) -> request_1.Request["EstimateRequest","EstimateResponse"]:
        """
        Estimates prices for a single resource.
        Returns both hourly and monthly cost estimates for the specified resource configuration.
        
        :param request: The request object to send.
        :type request: :class:`nebius.api.nebius.billing.v1alpha1.EstimateRequest`
        
        Other parameters can be provided as keyword arguments in the
        ``**kwargs`` dictionary, including metadata, timeouts, and retries.
        See :class:`nebius.aio.request_kwargs.RequestKwargs` for details.
        
        :return: A :class:`nebius.aio.request.Request` object representing the
            in-flight RPC. It can be awaited (async) or waited
            synchronously using its ``.wait()`` helpers.
        :rtype: :class:`nebius.aio.request.Request` of
            :class:`nebius.api.nebius.billing.v1alpha1.EstimateResponse`.
        """
        
        return super().request(
            method="Estimate",
            request=request,
            result_pb2_class=calculator_service_pb2.EstimateResponse,
            result_wrapper=pb_classes.simple_wrapper(EstimateResponse),
            **kwargs,
        )
    
    def estimate_batch(self,
        request: "EstimateBatchRequest",
        **kwargs: typing_extensions.Unpack[request_kwargs.RequestKwargs]
    ) -> request_1.Request["EstimateBatchRequest","EstimateBatchResponse"]:
        """
        Estimates prices for multiple resources.
        Returns aggregated hourly and monthly cost estimates for all specified resources.
        
        :param request: The request object to send.
        :type request: :class:`nebius.api.nebius.billing.v1alpha1.EstimateBatchRequest`
        
        Other parameters can be provided as keyword arguments in the
        ``**kwargs`` dictionary, including metadata, timeouts, and retries.
        See :class:`nebius.aio.request_kwargs.RequestKwargs` for details.
        
        :return: A :class:`nebius.aio.request.Request` object representing the
            in-flight RPC. It can be awaited (async) or waited
            synchronously using its ``.wait()`` helpers.
        :rtype: :class:`nebius.aio.request.Request` of
            :class:`nebius.api.nebius.billing.v1alpha1.EstimateBatchResponse`.
        """
        
        return super().request(
            method="EstimateBatch",
            request=request,
            result_pb2_class=calculator_service_pb2.EstimateBatchResponse,
            result_wrapper=pb_classes.simple_wrapper(EstimateBatchResponse),
            **kwargs,
        )
    

# file: nebius/billing/v1alpha1/one_time_export.proto
class OneTimeExportState(pb_enum.Enum):
    """
    Lifecycle states for one-time export.
    """
    
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.EnumDescriptor](".nebius.billing.v1alpha1.OneTimeExportState",one_time_export_pb2.DESCRIPTOR,descriptor_1.EnumDescriptor)
    ONE_TIME_EXPORT_STATE_UNSPECIFIED = 0
    ONE_TIME_EXPORT_STATE_SCHEDULED = 1
    """
    Export has been created and is scheduled for processing.
    """
    
    ONE_TIME_EXPORT_STATE_RUNNING = 2
    """
    Export is in progress.
    """
    
    ONE_TIME_EXPORT_STATE_SUCCESS = 3
    """
    Export completed successfully. Download URL is available.
    """
    
    ONE_TIME_EXPORT_STATE_FAILED = 4
    """
    Export failed. See error field for details.
    """
    
    ONE_TIME_EXPORT_STATE_ARCHIVED = 5
    """
    Export has been archived and the archive is no longer available for download.
    """
    

class OneTimeExport(pb_classes.Message):
    """
    One-time export of billing reports as a downloadable archive.
    Creates a .tar.gz archive of FOCUS billing data for the requested period
    and provides a presigned download URL.
    """
    
    __PB2_CLASS__ = one_time_export_pb2.OneTimeExport
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.billing.v1alpha1.OneTimeExport",one_time_export_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        metadata: "v1_2.ResourceMetadata|metadata_pb2.ResourceMetadata|None|unset.UnsetType" = unset.Unset,
        spec: "OneTimeExportSpec|one_time_export_pb2.OneTimeExportSpec|None|unset.UnsetType" = unset.Unset,
        status: "OneTimeExportStatus|one_time_export_pb2.OneTimeExportStatus|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(metadata, unset.UnsetType):
            self.metadata = metadata
        if not isinstance(spec, unset.UnsetType):
            self.spec = spec
        if not isinstance(status, unset.UnsetType):
            self.status = status
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "metadata",
            "spec",
            "status",
        ]
    
    @builtins.property
    def metadata(self) -> "v1_2.ResourceMetadata":
        """
        Parent is Contract ID.
        """
        
        return super()._get_field("metadata", explicit_presence=False,
        wrap=v1_2.ResourceMetadata,
        )
    @metadata.setter
    def metadata(self, value: "v1_2.ResourceMetadata|metadata_pb2.ResourceMetadata|None") -> None:
        return super()._set_field("metadata",value,explicit_presence=False,
        )
    
    @builtins.property
    def spec(self) -> "OneTimeExportSpec":
        """
        Export configuration specification.
        """
        
        return super()._get_field("spec", explicit_presence=False,
        wrap=OneTimeExportSpec,
        )
    @spec.setter
    def spec(self, value: "OneTimeExportSpec|one_time_export_pb2.OneTimeExportSpec|None") -> None:
        return super()._set_field("spec",value,explicit_presence=False,
        )
    
    @builtins.property
    def status(self) -> "OneTimeExportStatus":
        """
        Current status of the one-time export.
        """
        
        return super()._get_field("status", explicit_presence=False,
        wrap=OneTimeExportStatus,
        )
    @status.setter
    def status(self, value: "OneTimeExportStatus|one_time_export_pb2.OneTimeExportStatus|None") -> None:
        return super()._set_field("status",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "metadata":"metadata",
        "spec":"spec",
        "status":"status",
    }
    
class OneTimeExportSpec(pb_classes.Message):
    """
    Specification for one-time billing report export.
    """
    
    __PB2_CLASS__ = one_time_export_pb2.OneTimeExportSpec
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.billing.v1alpha1.OneTimeExportSpec",one_time_export_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        format: "ExportFormat|billing_report_exporter_pb2.ExportFormat|None|unset.UnsetType" = unset.Unset,
        start_period: "builtins.str|None|unset.UnsetType" = unset.Unset,
        end_period: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(format, unset.UnsetType):
            self.format = format
        if not isinstance(start_period, unset.UnsetType):
            self.start_period = start_period
        if not isinstance(end_period, unset.UnsetType):
            self.end_period = end_period
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "format",
            "start_period",
            "end_period",
        ]
    
    @builtins.property
    def format(self) -> "ExportFormat":
        """
        Format of the exported billing reports.
        """
        
        return super()._get_field("format", explicit_presence=False,
        wrap=ExportFormat,
        )
    @format.setter
    def format(self, value: "ExportFormat|billing_report_exporter_pb2.ExportFormat|None") -> None:
        return super()._set_field("format",value,explicit_presence=False,
        )
    
    @builtins.property
    def start_period(self) -> "builtins.str":
        """
        The first billing period to include in the export (inclusive).
        Example: "2025-04".
        """
        
        return super()._get_field("start_period", explicit_presence=False,
        )
    @start_period.setter
    def start_period(self, value: "builtins.str|None") -> None:
        return super()._set_field("start_period",value,explicit_presence=False,
        )
    
    @builtins.property
    def end_period(self) -> "builtins.str":
        """
        The last billing period to include in the export (inclusive).
        Example: "2025-06".
        """
        
        return super()._get_field("end_period", explicit_presence=False,
        )
    @end_period.setter
    def end_period(self, value: "builtins.str|None") -> None:
        return super()._set_field("end_period",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "format":"format",
        "start_period":"start_period",
        "end_period":"end_period",
    }
    
class OneTimeExportStatus(pb_classes.Message):
    """
    Status information for one-time export.
    """
    
    __PB2_CLASS__ = one_time_export_pb2.OneTimeExportStatus
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.billing.v1alpha1.OneTimeExportStatus",one_time_export_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
        "expires_at": well_known_1.ts_mask,
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        state: "OneTimeExportState|one_time_export_pb2.OneTimeExportState|None|unset.UnsetType" = unset.Unset,
        download_url: "builtins.str|None|unset.UnsetType" = unset.Unset,
        expires_at: "timestamp_pb2.Timestamp|datetime.datetime|None|unset.UnsetType" = unset.Unset,
        state_details: "OneTimeExportStateDetails|one_time_export_pb2.OneTimeExportStateDetails|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(state, unset.UnsetType):
            self.state = state
        if not isinstance(download_url, unset.UnsetType):
            self.download_url = download_url
        if not isinstance(expires_at, unset.UnsetType):
            self.expires_at = expires_at
        if not isinstance(state_details, unset.UnsetType):
            self.state_details = state_details
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "state",
            "download_url",
            "expires_at",
            "state_details",
        ]
    
    @builtins.property
    def state(self) -> "OneTimeExportState":
        """
        Current state of the export.
        """
        
        return super()._get_field("state", explicit_presence=False,
        wrap=OneTimeExportState,
        )
    @state.setter
    def state(self, value: "OneTimeExportState|one_time_export_pb2.OneTimeExportState|None") -> None:
        return super()._set_field("state",value,explicit_presence=False,
        )
    
    @builtins.property
    def download_url(self) -> "builtins.str":
        """
        Presigned download URL for the archive.
        Populated only when state is DONE. Each Get request generates a fresh URL.
        """
        
        return super()._get_field("download_url", explicit_presence=False,
        )
    @download_url.setter
    def download_url(self, value: "builtins.str|None") -> None:
        return super()._set_field("download_url",value,explicit_presence=False,
        )
    
    @builtins.property
    def expires_at(self) -> "datetime.datetime":
        """
        Timestamp when this export expires.
        """
        
        return super()._get_field("expires_at", explicit_presence=False,
        wrap=well_known_1.from_timestamp
        )
    @expires_at.setter
    def expires_at(self, value: "timestamp_pb2.Timestamp|datetime.datetime|None") -> None:
        return super()._set_field("expires_at",value,explicit_presence=False,
        unwrap=well_known_1.to_timestamp
        )
    
    @builtins.property
    def state_details(self) -> "OneTimeExportStateDetails":
        """
        Additional details about the current state.
        """
        
        return super()._get_field("state_details", explicit_presence=False,
        wrap=OneTimeExportStateDetails,
        )
    @state_details.setter
    def state_details(self, value: "OneTimeExportStateDetails|one_time_export_pb2.OneTimeExportStateDetails|None") -> None:
        return super()._set_field("state_details",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "state":"state",
        "download_url":"download_url",
        "expires_at":"expires_at",
        "state_details":"state_details",
    }
    
class OneTimeExportStateDetails(pb_classes.Message):
    """
    Additional details about the current state of the export.
    """
    
    __PB2_CLASS__ = one_time_export_pb2.OneTimeExportStateDetails
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.billing.v1alpha1.OneTimeExportStateDetails",one_time_export_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        error: "v1_2.ServiceError|error_pb2.ServiceError|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(error, unset.UnsetType):
            self.error = error
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "error",
        ]
    
    @builtins.property
    def error(self) -> "v1_2.ServiceError":
        """
        Error encountered during export.
        Populated only when state is FAILED.
        """
        
        return super()._get_field("error", explicit_presence=False,
        wrap=v1_2.ServiceError,
        )
    @error.setter
    def error(self, value: "v1_2.ServiceError|error_pb2.ServiceError|None") -> None:
        return super()._set_field("error",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "error":"error",
    }
    
# file: nebius/billing/v1alpha1/one_time_export_service.proto
class CreateOneTimeExportRequest(pb_classes.Message):
    __PB2_CLASS__ = one_time_export_service_pb2.CreateOneTimeExportRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.billing.v1alpha1.CreateOneTimeExportRequest",one_time_export_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        metadata: "v1_2.ResourceMetadata|metadata_pb2.ResourceMetadata|None|unset.UnsetType" = unset.Unset,
        spec: "OneTimeExportSpec|one_time_export_pb2.OneTimeExportSpec|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(metadata, unset.UnsetType):
            self.metadata = metadata
        if not isinstance(spec, unset.UnsetType):
            self.spec = spec
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "metadata",
            "spec",
        ]
    
    @builtins.property
    def metadata(self) -> "v1_2.ResourceMetadata":
        """
        Resource metadata including parent contract ID.
        """
        
        return super()._get_field("metadata", explicit_presence=False,
        wrap=v1_2.ResourceMetadata,
        )
    @metadata.setter
    def metadata(self, value: "v1_2.ResourceMetadata|metadata_pb2.ResourceMetadata|None") -> None:
        return super()._set_field("metadata",value,explicit_presence=False,
        )
    
    @builtins.property
    def spec(self) -> "OneTimeExportSpec":
        """
        Export configuration specification.
        """
        
        return super()._get_field("spec", explicit_presence=False,
        wrap=OneTimeExportSpec,
        )
    @spec.setter
    def spec(self, value: "OneTimeExportSpec|one_time_export_pb2.OneTimeExportSpec|None") -> None:
        return super()._set_field("spec",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "metadata":"metadata",
        "spec":"spec",
    }
    
class GetOneTimeExportRequest(pb_classes.Message):
    __PB2_CLASS__ = one_time_export_service_pb2.GetOneTimeExportRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.billing.v1alpha1.GetOneTimeExportRequest",one_time_export_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        id: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(id, unset.UnsetType):
            self.id = id
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "id",
        ]
    
    @builtins.property
    def id(self) -> "builtins.str":
        """
        Unique identifier of the one-time export.
        """
        
        return super()._get_field("id", explicit_presence=False,
        )
    @id.setter
    def id(self, value: "builtins.str|None") -> None:
        return super()._set_field("id",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "id":"id",
    }
    
class ListOneTimeExportsRequest(pb_classes.Message):
    __PB2_CLASS__ = one_time_export_service_pb2.ListOneTimeExportsRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.billing.v1alpha1.ListOneTimeExportsRequest",one_time_export_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        parent_id: "builtins.str|None|unset.UnsetType" = unset.Unset,
        page_size: "builtins.int|None|unset.UnsetType" = unset.Unset,
        page_token: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(parent_id, unset.UnsetType):
            self.parent_id = parent_id
        if not isinstance(page_size, unset.UnsetType):
            self.page_size = page_size
        if not isinstance(page_token, unset.UnsetType):
            self.page_token = page_token
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "parent_id",
            "page_size",
            "page_token",
        ]
    
    @builtins.property
    def parent_id(self) -> "builtins.str":
        """
        Parent contract ID for which to list one-time exports.
        """
        
        return super()._get_field("parent_id", explicit_presence=False,
        )
    @parent_id.setter
    def parent_id(self, value: "builtins.str|None") -> None:
        return super()._set_field("parent_id",value,explicit_presence=False,
        )
    
    @builtins.property
    def page_size(self) -> "builtins.int":
        """
        Maximum number of items to return per page.
        """
        
        return super()._get_field("page_size", explicit_presence=False,
        )
    @page_size.setter
    def page_size(self, value: "builtins.int|None") -> None:
        return super()._set_field("page_size",value,explicit_presence=False,
        )
    
    @builtins.property
    def page_token(self) -> "builtins.str":
        """
        Token for retrieving the next page of results.
        """
        
        return super()._get_field("page_token", explicit_presence=False,
        )
    @page_token.setter
    def page_token(self, value: "builtins.str|None") -> None:
        return super()._set_field("page_token",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "parent_id":"parent_id",
        "page_size":"page_size",
        "page_token":"page_token",
    }
    
class ListOneTimeExportsResponse(pb_classes.Message):
    __PB2_CLASS__ = one_time_export_service_pb2.ListOneTimeExportsResponse
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.billing.v1alpha1.ListOneTimeExportsResponse",one_time_export_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        items: "abc.Iterable[OneTimeExport]|None|unset.UnsetType" = unset.Unset,
        next_page_token: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(items, unset.UnsetType):
            self.items = items
        if not isinstance(next_page_token, unset.UnsetType):
            self.next_page_token = next_page_token
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "items",
            "next_page_token",
        ]
    
    @builtins.property
    def items(self) -> "abc.MutableSequence[OneTimeExport]":
        """
        List of one-time exports for the specified contract.
        """
        
        return super()._get_field("items", explicit_presence=False,
        wrap=pb_classes.Repeated.with_wrap(OneTimeExport,None,None),
        )
    @items.setter
    def items(self, value: "abc.Iterable[OneTimeExport]|None") -> None:
        return super()._set_field("items",value,explicit_presence=False,
        )
    
    @builtins.property
    def next_page_token(self) -> "builtins.str":
        """
        Token for retrieving the next page of results. Empty if no more pages.
        """
        
        return super()._get_field("next_page_token", explicit_presence=False,
        )
    @next_page_token.setter
    def next_page_token(self, value: "builtins.str|None") -> None:
        return super()._set_field("next_page_token",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "items":"items",
        "next_page_token":"next_page_token",
    }
    

class OneTimeExportServiceClient(client.ClientWithOperations[v1_2.Operation,v1_2.OperationServiceClient]):
    """
    Service for managing one-time billing report exports.
    Enables creation of downloadable archives of billing data for a specified period.
    
    This class provides the client methods for the ``.nebius.billing.v1alpha1.OneTimeExportService`` service.
    
    Each method constructs a :class:`nebius.aio.request.Request` object
    that represents the in-flight RPC. The request can be awaited (async)
    or waited synchronously using its ``.wait()`` helpers.
    
    The request methods accept various parameters to configure metadata,
    timeouts, authorization, and retries. See individual method docstrings
    for details.
    
    :cvar __service_name__: The full protobuf service name.
    """
    
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.ServiceDescriptor](".nebius.billing.v1alpha1.OneTimeExportService",one_time_export_service_pb2.DESCRIPTOR,descriptor_1.ServiceDescriptor)
    """The protobuf service descriptor extraction function."""
    __service_name__ = ".nebius.billing.v1alpha1.OneTimeExportService"
    __operation_type__ = v1_2.Operation
    __operation_service_class__ = v1_2.OperationServiceClient
    __operation_source_method__ = "Create"
    """The method name that can be used to fetch the address channel for the operation."""
    
    def create(self,
        request: "CreateOneTimeExportRequest",
        **kwargs: typing_extensions.Unpack[request_kwargs.RequestKwargs]
    ) -> request_1.Request["CreateOneTimeExportRequest","operation.Operation[v1_2.Operation]"]:
        """
        Creates a new one-time export of billing reports for the requested period.
        
        :param request: The request object to send.
        :type request: :class:`nebius.api.nebius.billing.v1alpha1.CreateOneTimeExportRequest`
        
        Other parameters can be provided as keyword arguments in the
        ``**kwargs`` dictionary, including metadata, timeouts, and retries.
        See :class:`nebius.aio.request_kwargs.RequestKwargs` for details.
        
        :return: A :class:`nebius.aio.request.Request` object representing the
            in-flight RPC. It can be awaited (async) or waited
            synchronously using its ``.wait()`` helpers.
        :rtype: :class:`nebius.aio.request.Request` of
            :class:`nebius.api.nebius.common.v1.Operation`.
        """
        
        return super().request(
            method="Create",
            request=request,
            result_pb2_class=operation_pb2.Operation,
            result_wrapper=operation.Operation,
            **kwargs,
        )
    
    def get(self,
        request: "GetOneTimeExportRequest",
        **kwargs: typing_extensions.Unpack[request_kwargs.RequestKwargs]
    ) -> request_1.Request["GetOneTimeExportRequest","OneTimeExport"]:
        """
        Retrieves details of a specific one-time export.
        When the export is complete, the response includes a fresh presigned download URL.
        
        :param request: The request object to send.
        :type request: :class:`nebius.api.nebius.billing.v1alpha1.GetOneTimeExportRequest`
        
        Other parameters can be provided as keyword arguments in the
        ``**kwargs`` dictionary, including metadata, timeouts, and retries.
        See :class:`nebius.aio.request_kwargs.RequestKwargs` for details.
        
        :return: A :class:`nebius.aio.request.Request` object representing the
            in-flight RPC. It can be awaited (async) or waited
            synchronously using its ``.wait()`` helpers.
        :rtype: :class:`nebius.aio.request.Request` of
            :class:`nebius.api.nebius.billing.v1alpha1.OneTimeExport`.
        """
        
        return super().request(
            method="Get",
            request=request,
            result_pb2_class=one_time_export_pb2.OneTimeExport,
            result_wrapper=pb_classes.simple_wrapper(OneTimeExport),
            **kwargs,
        )
    
    def list(self,
        request: "ListOneTimeExportsRequest",
        **kwargs: typing_extensions.Unpack[request_kwargs.RequestKwargs]
    ) -> request_1.Request["ListOneTimeExportsRequest","ListOneTimeExportsResponse"]:
        """
        Lists one-time exports for a given contract.
        
        :param request: The request object to send.
        :type request: :class:`nebius.api.nebius.billing.v1alpha1.ListOneTimeExportsRequest`
        
        Other parameters can be provided as keyword arguments in the
        ``**kwargs`` dictionary, including metadata, timeouts, and retries.
        See :class:`nebius.aio.request_kwargs.RequestKwargs` for details.
        
        :return: A :class:`nebius.aio.request.Request` object representing the
            in-flight RPC. It can be awaited (async) or waited
            synchronously using its ``.wait()`` helpers.
        :rtype: :class:`nebius.aio.request.Request` of
            :class:`nebius.api.nebius.billing.v1alpha1.ListOneTimeExportsResponse`.
        """
        
        return super().request(
            method="List",
            request=request,
            result_pb2_class=one_time_export_service_pb2.ListOneTimeExportsResponse,
            result_wrapper=pb_classes.simple_wrapper(ListOneTimeExportsResponse),
            **kwargs,
        )
    

__all__ = [
    #@ local import names here @#
    "ExportFormat",
    "ResourceSpec",
    "ResourceGroupCost",
    "GeneralTotalCost",
    "GeneralResourceCost",
    "CostBreakdown",
    "OfferType",
    "EstimateRequest",
    "EstimateResponse",
    "EstimateBatchRequest",
    "EstimateBatchResponse",
    "CalculatorServiceClient",
    "OneTimeExportState",
    "OneTimeExport",
    "OneTimeExportSpec",
    "OneTimeExportStatus",
    "OneTimeExportStateDetails",
    "CreateOneTimeExportRequest",
    "GetOneTimeExportRequest",
    "ListOneTimeExportsRequest",
    "ListOneTimeExportsResponse",
    "OneTimeExportServiceClient",
]



from nebius.api.buf.validate import validate_pb2 as _validate_pb2
from nebius.api.nebius import annotations_pb2 as _annotations_pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as _metadata_pb2
from nebius.api.nebius.compute.v1 import disk_pb2 as _disk_pb2
from nebius.api.nebius.compute.v1 import instance_pb2 as _instance_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Endpoint(_message.Message):
    __slots__ = ["metadata", "spec", "status"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SPEC_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.ResourceMetadata
    spec: EndpointSpec
    status: EndpointStatus
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.ResourceMetadata, _Mapping]] = ..., spec: _Optional[_Union[EndpointSpec, _Mapping]] = ..., status: _Optional[_Union[EndpointStatus, _Mapping]] = ...) -> None: ...

class EndpointSpec(_message.Message):
    __slots__ = ["image", "environment_variables", "ports", "container_command", "args", "working_dir", "volumes", "registry_credentials", "platform", "preset", "shm_size_bytes", "disk", "subnet_id", "public_ip", "ssh_authorized_keys", "preemptible", "auth_token"]
    class EnvironmentVariable(_message.Message):
        __slots__ = ["name", "value"]
        NAME_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        name: str
        value: str
        def __init__(self, name: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    class Port(_message.Message):
        __slots__ = ["container_port", "host_port", "protocol"]
        class Protocol(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = []
            PROTOCOL_UNSPECIFIED: _ClassVar[EndpointSpec.Port.Protocol]
            HTTP: _ClassVar[EndpointSpec.Port.Protocol]
            TCP: _ClassVar[EndpointSpec.Port.Protocol]
            UDP: _ClassVar[EndpointSpec.Port.Protocol]
        PROTOCOL_UNSPECIFIED: EndpointSpec.Port.Protocol
        HTTP: EndpointSpec.Port.Protocol
        TCP: EndpointSpec.Port.Protocol
        UDP: EndpointSpec.Port.Protocol
        CONTAINER_PORT_FIELD_NUMBER: _ClassVar[int]
        HOST_PORT_FIELD_NUMBER: _ClassVar[int]
        PROTOCOL_FIELD_NUMBER: _ClassVar[int]
        container_port: int
        host_port: int
        protocol: EndpointSpec.Port.Protocol
        def __init__(self, container_port: _Optional[int] = ..., host_port: _Optional[int] = ..., protocol: _Optional[_Union[EndpointSpec.Port.Protocol, str]] = ...) -> None: ...
    class VolumeMount(_message.Message):
        __slots__ = ["source", "source_path", "container_path", "mode", "s3_config"]
        class Mode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = []
            MODE_UNSPECIFIED: _ClassVar[EndpointSpec.VolumeMount.Mode]
            READ_ONLY: _ClassVar[EndpointSpec.VolumeMount.Mode]
            READ_WRITE: _ClassVar[EndpointSpec.VolumeMount.Mode]
        MODE_UNSPECIFIED: EndpointSpec.VolumeMount.Mode
        READ_ONLY: EndpointSpec.VolumeMount.Mode
        READ_WRITE: EndpointSpec.VolumeMount.Mode
        class S3Config(_message.Message):
            __slots__ = ["endpoint", "region", "credentials"]
            class S3Credentials(_message.Message):
                __slots__ = ["access_key_id", "secret_access_key", "session_token"]
                ACCESS_KEY_ID_FIELD_NUMBER: _ClassVar[int]
                SECRET_ACCESS_KEY_FIELD_NUMBER: _ClassVar[int]
                SESSION_TOKEN_FIELD_NUMBER: _ClassVar[int]
                access_key_id: str
                secret_access_key: str
                session_token: str
                def __init__(self, access_key_id: _Optional[str] = ..., secret_access_key: _Optional[str] = ..., session_token: _Optional[str] = ...) -> None: ...
            ENDPOINT_FIELD_NUMBER: _ClassVar[int]
            REGION_FIELD_NUMBER: _ClassVar[int]
            CREDENTIALS_FIELD_NUMBER: _ClassVar[int]
            endpoint: str
            region: str
            credentials: EndpointSpec.VolumeMount.S3Config.S3Credentials
            def __init__(self, endpoint: _Optional[str] = ..., region: _Optional[str] = ..., credentials: _Optional[_Union[EndpointSpec.VolumeMount.S3Config.S3Credentials, _Mapping]] = ...) -> None: ...
        SOURCE_FIELD_NUMBER: _ClassVar[int]
        SOURCE_PATH_FIELD_NUMBER: _ClassVar[int]
        CONTAINER_PATH_FIELD_NUMBER: _ClassVar[int]
        MODE_FIELD_NUMBER: _ClassVar[int]
        S3_CONFIG_FIELD_NUMBER: _ClassVar[int]
        source: str
        source_path: str
        container_path: str
        mode: EndpointSpec.VolumeMount.Mode
        s3_config: EndpointSpec.VolumeMount.S3Config
        def __init__(self, source: _Optional[str] = ..., source_path: _Optional[str] = ..., container_path: _Optional[str] = ..., mode: _Optional[_Union[EndpointSpec.VolumeMount.Mode, str]] = ..., s3_config: _Optional[_Union[EndpointSpec.VolumeMount.S3Config, _Mapping]] = ...) -> None: ...
    class DiskSpec(_message.Message):
        __slots__ = ["type", "size_bytes"]
        TYPE_FIELD_NUMBER: _ClassVar[int]
        SIZE_BYTES_FIELD_NUMBER: _ClassVar[int]
        type: _disk_pb2.DiskSpec.DiskType
        size_bytes: int
        def __init__(self, type: _Optional[_Union[_disk_pb2.DiskSpec.DiskType, str]] = ..., size_bytes: _Optional[int] = ...) -> None: ...
    class RegistryCredentials(_message.Message):
        __slots__ = ["username", "password", "mysterybox_secret_version"]
        USERNAME_FIELD_NUMBER: _ClassVar[int]
        PASSWORD_FIELD_NUMBER: _ClassVar[int]
        MYSTERYBOX_SECRET_VERSION_FIELD_NUMBER: _ClassVar[int]
        username: str
        password: str
        mysterybox_secret_version: str
        def __init__(self, username: _Optional[str] = ..., password: _Optional[str] = ..., mysterybox_secret_version: _Optional[str] = ...) -> None: ...
    IMAGE_FIELD_NUMBER: _ClassVar[int]
    ENVIRONMENT_VARIABLES_FIELD_NUMBER: _ClassVar[int]
    PORTS_FIELD_NUMBER: _ClassVar[int]
    CONTAINER_COMMAND_FIELD_NUMBER: _ClassVar[int]
    ARGS_FIELD_NUMBER: _ClassVar[int]
    WORKING_DIR_FIELD_NUMBER: _ClassVar[int]
    VOLUMES_FIELD_NUMBER: _ClassVar[int]
    REGISTRY_CREDENTIALS_FIELD_NUMBER: _ClassVar[int]
    PLATFORM_FIELD_NUMBER: _ClassVar[int]
    PRESET_FIELD_NUMBER: _ClassVar[int]
    SHM_SIZE_BYTES_FIELD_NUMBER: _ClassVar[int]
    DISK_FIELD_NUMBER: _ClassVar[int]
    SUBNET_ID_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_IP_FIELD_NUMBER: _ClassVar[int]
    SSH_AUTHORIZED_KEYS_FIELD_NUMBER: _ClassVar[int]
    PREEMPTIBLE_FIELD_NUMBER: _ClassVar[int]
    AUTH_TOKEN_FIELD_NUMBER: _ClassVar[int]
    image: str
    environment_variables: _containers.RepeatedCompositeFieldContainer[EndpointSpec.EnvironmentVariable]
    ports: _containers.RepeatedCompositeFieldContainer[EndpointSpec.Port]
    container_command: str
    args: str
    working_dir: str
    volumes: _containers.RepeatedCompositeFieldContainer[EndpointSpec.VolumeMount]
    registry_credentials: EndpointSpec.RegistryCredentials
    platform: str
    preset: str
    shm_size_bytes: int
    disk: EndpointSpec.DiskSpec
    subnet_id: str
    public_ip: bool
    ssh_authorized_keys: _containers.RepeatedScalarFieldContainer[str]
    preemptible: bool
    auth_token: str
    def __init__(self, image: _Optional[str] = ..., environment_variables: _Optional[_Iterable[_Union[EndpointSpec.EnvironmentVariable, _Mapping]]] = ..., ports: _Optional[_Iterable[_Union[EndpointSpec.Port, _Mapping]]] = ..., container_command: _Optional[str] = ..., args: _Optional[str] = ..., working_dir: _Optional[str] = ..., volumes: _Optional[_Iterable[_Union[EndpointSpec.VolumeMount, _Mapping]]] = ..., registry_credentials: _Optional[_Union[EndpointSpec.RegistryCredentials, _Mapping]] = ..., platform: _Optional[str] = ..., preset: _Optional[str] = ..., shm_size_bytes: _Optional[int] = ..., disk: _Optional[_Union[EndpointSpec.DiskSpec, _Mapping]] = ..., subnet_id: _Optional[str] = ..., public_ip: bool = ..., ssh_authorized_keys: _Optional[_Iterable[str]] = ..., preemptible: bool = ..., auth_token: _Optional[str] = ...) -> None: ...

class EndpointStatus(_message.Message):
    __slots__ = ["private_endpoints", "public_endpoints", "instances", "state", "state_details"]
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        STATE_UNSPECIFIED: _ClassVar[EndpointStatus.State]
        PROVISIONING: _ClassVar[EndpointStatus.State]
        STARTING: _ClassVar[EndpointStatus.State]
        RUNNING: _ClassVar[EndpointStatus.State]
        STOPPING: _ClassVar[EndpointStatus.State]
        DELETING: _ClassVar[EndpointStatus.State]
        STOPPED: _ClassVar[EndpointStatus.State]
        ERROR: _ClassVar[EndpointStatus.State]
    STATE_UNSPECIFIED: EndpointStatus.State
    PROVISIONING: EndpointStatus.State
    STARTING: EndpointStatus.State
    RUNNING: EndpointStatus.State
    STOPPING: EndpointStatus.State
    DELETING: EndpointStatus.State
    STOPPED: EndpointStatus.State
    ERROR: EndpointStatus.State
    PRIVATE_ENDPOINTS_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_ENDPOINTS_FIELD_NUMBER: _ClassVar[int]
    INSTANCES_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    STATE_DETAILS_FIELD_NUMBER: _ClassVar[int]
    private_endpoints: _containers.RepeatedScalarFieldContainer[str]
    public_endpoints: _containers.RepeatedScalarFieldContainer[str]
    instances: _containers.RepeatedCompositeFieldContainer[EndpointInstanceStatus]
    state: EndpointStatus.State
    state_details: EndpointStateDetails
    def __init__(self, private_endpoints: _Optional[_Iterable[str]] = ..., public_endpoints: _Optional[_Iterable[str]] = ..., instances: _Optional[_Iterable[_Union[EndpointInstanceStatus, _Mapping]]] = ..., state: _Optional[_Union[EndpointStatus.State, str]] = ..., state_details: _Optional[_Union[EndpointStateDetails, _Mapping]] = ...) -> None: ...

class EndpointStateDetails(_message.Message):
    __slots__ = ["code", "message"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    code: str
    message: str
    def __init__(self, code: _Optional[str] = ..., message: _Optional[str] = ...) -> None: ...

class EndpointInstanceStatus(_message.Message):
    __slots__ = ["state", "compute_instance_id", "compute_instance_state", "private_ip", "public_ip"]
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        STATE_UNSPECIFIED: _ClassVar[EndpointInstanceStatus.State]
        PROVISIONING: _ClassVar[EndpointInstanceStatus.State]
        STARTING: _ClassVar[EndpointInstanceStatus.State]
        RUNNING: _ClassVar[EndpointInstanceStatus.State]
        STOPPING: _ClassVar[EndpointInstanceStatus.State]
        DELETING: _ClassVar[EndpointInstanceStatus.State]
        STOPPED: _ClassVar[EndpointInstanceStatus.State]
        FAILED: _ClassVar[EndpointInstanceStatus.State]
        ERROR: _ClassVar[EndpointInstanceStatus.State]
    STATE_UNSPECIFIED: EndpointInstanceStatus.State
    PROVISIONING: EndpointInstanceStatus.State
    STARTING: EndpointInstanceStatus.State
    RUNNING: EndpointInstanceStatus.State
    STOPPING: EndpointInstanceStatus.State
    DELETING: EndpointInstanceStatus.State
    STOPPED: EndpointInstanceStatus.State
    FAILED: EndpointInstanceStatus.State
    ERROR: EndpointInstanceStatus.State
    STATE_FIELD_NUMBER: _ClassVar[int]
    COMPUTE_INSTANCE_ID_FIELD_NUMBER: _ClassVar[int]
    COMPUTE_INSTANCE_STATE_FIELD_NUMBER: _ClassVar[int]
    PRIVATE_IP_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_IP_FIELD_NUMBER: _ClassVar[int]
    state: EndpointInstanceStatus.State
    compute_instance_id: str
    compute_instance_state: _instance_pb2.InstanceStatus.InstanceState
    private_ip: str
    public_ip: str
    def __init__(self, state: _Optional[_Union[EndpointInstanceStatus.State, str]] = ..., compute_instance_id: _Optional[str] = ..., compute_instance_state: _Optional[_Union[_instance_pb2.InstanceStatus.InstanceState, str]] = ..., private_ip: _Optional[str] = ..., public_ip: _Optional[str] = ...) -> None: ...



from nebius.api.buf.validate import validate_pb2 as _validate_pb2
from google.rpc import status_pb2 as _status_pb2
from nebius.api.nebius import annotations_pb2 as _annotations_pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as _metadata_pb2
from nebius.api.nebius.common.v1 import operation_pb2 as _operation_pb2
from nebius.api.nebius.common.v1 import operation_service_pb2 as _operation_service_pb2
from nebius.api.nebius.compute.v1 import instance_pb2 as _instance_pb2
from nebius.api.nebius.compute.v1 import operation_service_pb2 as _operation_service_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetInstanceRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class ListInstancesRequest(_message.Message):
    __slots__ = ["parent_id", "page_size", "page_token"]
    PARENT_ID_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    parent_id: str
    page_size: int
    page_token: str
    def __init__(self, parent_id: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ...) -> None: ...

class CreateInstanceRequest(_message.Message):
    __slots__ = ["metadata", "spec"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SPEC_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.ResourceMetadata
    spec: _instance_pb2.InstanceSpec
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.ResourceMetadata, _Mapping]] = ..., spec: _Optional[_Union[_instance_pb2.InstanceSpec, _Mapping]] = ...) -> None: ...

class UpdateInstanceRequest(_message.Message):
    __slots__ = ["metadata", "spec"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SPEC_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.ResourceMetadata
    spec: _instance_pb2.InstanceSpec
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.ResourceMetadata, _Mapping]] = ..., spec: _Optional[_Union[_instance_pb2.InstanceSpec, _Mapping]] = ...) -> None: ...

class DeleteInstanceRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class ListInstancesResponse(_message.Message):
    __slots__ = ["items", "next_page_token"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_instance_pb2.Instance]
    next_page_token: str
    def __init__(self, items: _Optional[_Iterable[_Union[_instance_pb2.Instance, _Mapping]]] = ..., next_page_token: _Optional[str] = ...) -> None: ...

class StartInstanceRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class StopInstanceRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class BatchGetRequest(_message.Message):
    __slots__ = ["instance_ids"]
    INSTANCE_IDS_FIELD_NUMBER: _ClassVar[int]
    instance_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, instance_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class BatchGetResponse(_message.Message):
    __slots__ = ["items"]
    class BatchGetResult(_message.Message):
        __slots__ = ["instance", "error"]
        INSTANCE_FIELD_NUMBER: _ClassVar[int]
        ERROR_FIELD_NUMBER: _ClassVar[int]
        instance: _instance_pb2.Instance
        error: _status_pb2.Status
        def __init__(self, instance: _Optional[_Union[_instance_pb2.Instance, _Mapping]] = ..., error: _Optional[_Union[_status_pb2.Status, _Mapping]] = ...) -> None: ...
    class ItemsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: BatchGetResponse.BatchGetResult
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[BatchGetResponse.BatchGetResult, _Mapping]] = ...) -> None: ...
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    items: _containers.MessageMap[str, BatchGetResponse.BatchGetResult]
    def __init__(self, items: _Optional[_Mapping[str, BatchGetResponse.BatchGetResult]] = ...) -> None: ...
